// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"
#include "Rivet/Projections/FastJets.hh"
#include "Rivet/Tools/BinnedHistogram.hh"

namespace Rivet {

  // This analysis is a derived from the class Analysis:
  class CMS_2013_I1208923_DIJETMASS : public Analysis {


  private:
    BinnedHistogram<double> _h_invMass;

  public:
    // Constructor
    CMS_2013_I1208923_DIJETMASS()
      : Analysis("CMS_2013_I1208923_DIJETMASS") {
      setNeedsCrossSection(true);
    }

    // Book histograms and initialize projections:
    void init() {
      const FinalState fs;
      addProjection(fs, "FS");

      // Initialize the projectors:
      addProjection(FastJets(fs, FastJets::ANTIKT, 0.7), "Jets");

      // Book histograms:
      _h_invMass.addHistogram(0.0, 0.5, bookHisto1D(1, 1, 1));
      _h_invMass.addHistogram(0.5, 1.0, bookHisto1D(2, 1, 1));
      _h_invMass.addHistogram(1.0, 1.5, bookHisto1D(3, 1, 1));
      _h_invMass.addHistogram(1.5, 2.0, bookHisto1D(4, 1, 1));
      _h_invMass.addHistogram(2.0, 2.5, bookHisto1D(5, 1, 1));
    }

    // Analysis
    void analyze(const Event &event) {
      const double weight = event.weight();
      const FastJets &fJets = applyProjection<FastJets>(event,"Jets");
      const Jets& jets = fJets.jetsByPt(25. * GeV, MAXDOUBLE, -2.5, 2.5, RAPIDITY);

      // Require two jets
      if (jets.size() < 2)
        vetoEvent;

      double jet1 = jets[0].momentum().pT() / GeV;
      double jet2 = jets[1].momentum().pT() / GeV;

      if (jet1 > 60. && jet2 > 30.) {
        // Fill the invariant mass histogram
        double ymax = max(jets[0].momentum().absrapidity(), jets[1].momentum().absrapidity());
        double invMass = FourMomentum(jets[0].momentum() + jets[1].momentum()).mass();
        _h_invMass.fill(fabs(ymax), invMass, weight);
      }
    }


    // Scale histograms according to cross section
    void finalize() {
      _h_invMass.scale(crossSection() / sumOfWeights() / 2, this);
    }
  };

  // This global object acts as a hook for the plugin system.
  DECLARE_RIVET_PLUGIN(CMS_2013_I1208923_DIJETMASS);
}
