// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"
#include "Rivet/Projections/FastJets.hh"
#include "Rivet/Tools/BinnedHistogram.hh"

namespace Rivet {

  // This analysis is a derived from the class Analysis:
  class CMS_2013_I1208923_JETPT : public Analysis {

  public:
    // Constructor
    CMS_2013_I1208923_JETPT()
      : Analysis("CMS_2013_I1208923_JETPT") {
      setNeedsCrossSection(true);
    }

    // Book histograms and initialize projections:
    void init() {
      const FinalState fs;
      addProjection(fs, "FS");

      // Initialize the projections
      addProjection(FastJets(fs, FastJets::ANTIKT, 0.7), "Jets");

      // Book histograms
      _h_sigma.addHistogram(0.0, 0.5, bookHisto1D(1, 1, 1));
      _h_sigma.addHistogram(0.5, 1.0, bookHisto1D(2, 1, 1));
      _h_sigma.addHistogram(1.0, 1.5, bookHisto1D(3, 1, 1));
      _h_sigma.addHistogram(1.5, 2.0, bookHisto1D(4, 1, 1));
      _h_sigma.addHistogram(2.0, 2.5, bookHisto1D(5, 1, 1));
    }

    // Analysis
    void analyze(const Event &event) {
      const double weight = event.weight();
      const FastJets &fJets = applyProjection<FastJets>(event, "Jets");
      const Jets& jets = fJets.jetsByPt(100. * GeV, MAXDOUBLE, -2.5, 2.5, RAPIDITY);

      // Fill the jet pT spectra
      foreach (const Jet &j, jets) {
        _h_sigma.fill(fabs(j.momentum().rapidity()), j.momentum().pT() / GeV, weight);
      }
    }


    // Scale histograms by the production cross section
    void finalize() {
      _h_sigma.scale(crossSection() / sumOfWeights() / 2.0, this);
    }

  private:
    BinnedHistogram<double> _h_sigma;
  };

  // This global object acts as a hook for the plugin system.
  DECLARE_RIVET_PLUGIN(CMS_2013_I1208923_JETPT);
}
